#
# spec file for package spotify-qt
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           spotify-qt
Version:        3.9
Release:        bp155.1.12
Summary:        Lightweight Spotify client using Qt
License:        GPL-3.0-only
URL:            https://github.com/kraxarn/spotify-qt
Source:         https://github.com/kraxarn/spotify-qt/archive/refs/tags/v%{version}.tar.gz
Group:          Productivity/Multimedia/Sound/Players
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Svg)
Suggests:       spotifyd

%description
An unofficial Spotify client using Qt as a simpler, lighter alternative to the official client, inspired by spotify-tui. Much like spotify-tui, you need an actual Spotify client running, for example spotifyd, which can be configured from within the app. Also like other clients, controlling music playback requires Spotify Premium.

%prep
%setup -q

%build
%cmake
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%license license
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/icons/hicolor/scalable/
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Thu Aug 11 2022 Jens K. <karatekhd@opensuse.org>
- Update to version 3.9
  - Fixes
  * Fixed not being able to move window under Wayland.
  * Fixed showing add and remove options for tracks in collaborative playlists.
  * Fixed some possible issues with selecting a device.
  * Fixed MPRIS support under KDE.
  * Fixed crash when opening links on some artists.
  - Changes
  * Much improved MPRIS support.
  * Added keyboard shortcuts.
  * Added support for playing tracks from outside the application.
  * Added support for selecting multiple tracks.
  * Added an option to use an expanded album cover.
  * Added an option to close application to the tray.
  * Improved detection of spotifyd config files.
  * Added an option to change device type.
  * Added message when queuing tracks.
  * Replaced custom font option with ability to select font from system.
  * Added an option to disable checking for updates on start.
* Tue Jan 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Clean up spec file a bit:
  + Drop empty post/postubn scriptlets
  + Remove not used requires on hicolor-icon-theme,
    shared-mime-info, and update-desktop-files.
  + Package license file.
  + Set license to GPL-3.0-only: there is no indication that
    GPL-3.0-or-later is valid.
* Mon Jan 17 2022 Jens K. <karatekhd@opensuse.org>
- Update to version 3.8:
  - Fixes
  * Fixed empty context menu when right-clicking empty spaces.
  * Fixed not updating playlist when deleting a track.
  * Fixed incorrect track order after deleting a track in a playlist.
  * Fixed paging not working with some lists.
  * Fixed not removing extra spacing when using system title bar.
  * Fixed issues with followed playlists by other users not updating properly.
  * Fixed issue when attempting to search for nothing.
  * Fixed issues resuming playback when last used device was no longer available.
  - Changes
  * Added an option to show desktop notification on track change.
  * Added support for repeating a single track.
  * Added support for podcasts.
  * New and improved volume slider.
  * Already opened artists are now re-used.
  * Added support for mirrored title bar buttons.
  * Added support for creating new playlists.
  * Added support for following, and unfollowing, playlists.
  * New status messages, replacing the status bar and desktop notifications.
  * Added a custom font for the custom dark theme.
  * Now continues playing tracks from search results.
  * Now shows more artists links, for example social media links.
  * Removed broken "PulseAudio volume control" setting.
  * Tracks in albums now show an added date for when the album released.
  * New categories in settings for logs and for troubleshooting.
* Sun Aug 15 2021 Jens K. <jens@karatek.net>
- Bump version to 3.7
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Add description.
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Stuff
* Mon May 17 2021 Jens K. <karatek@karatek.net>
- Initial Commit
